==> boostcrm-widget-1.0.2.tgz: package/es/store/actions/stop-call.actions.js <==
import _regeneratorRuntime from 'babel-runtime/regenerator';
import _extends from 'babel-runtime/helpers/extends';
import _asyncToGenerator from 'babel-runtime/helpers/asyncToGenerator';
import _get from 'lodash/get';
import * as actions from './action-type';
import { createAction } from 'redux-actions';
import { sendMessage } from '../../connections/websocket';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';
import webRTC from '../../components/phone-call/webrtc';
import { CALL_STATUS, CALL_STOP_REASON } from '../../components/phone-call/constants';


export var stopCallRequest = createAction(actions.STOP_CALL + '.REQUEST');
export var stopCall = function stopCall(callInfo, _ref) {
  var stopReason = _ref.stopReason,
      totalDuration = _ref.totalDuration;

  return function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch) {
      var payload;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // webRTC stop call
              webRTC.stopCall();

              if (_get(callInfo, 'id')) {
                _context.next = 3;
                break;
              }

              return _context.abrupt('return');

            case 3:
              payload = _extends({}, callInfo, {
                stopReason: stopReason,
                totalDuration: stopReason === CALL_STOP_REASON.SUBSCRIBER_AUTO_STOP_WHEN_TIMEOUT ? 0 : totalDuration,
                status: stopReason === CALL_STOP_REASON.SUBSCRIBER_AUTO_STOP_WHEN_TIMEOUT || callInfo.status !== CALL_STATUS.IN_PROGRESS ? CALL_STATUS.CUSTOMER_CANCELED : CALL_STATUS.COMPLETED
              });


              dispatch(stopCallRequest({ status: payload.status }));
              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.STOP_CALL,
                payload: payload,
                tenantInfo: getTenantInfo()
              });

            case 6:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    return function (_x) {
      return _ref2.apply(this, arguments);
    };
  }();
};

==> boostcrm-widget-1.0.8.tgz: package/es/store/actions/stop-call.actions.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _get from "lodash/get";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as actions from './action-type';
import { createAction } from 'redux-actions';
import { sendMessage } from '../../connections/websocket';
import { GROUP, TYPE } from '../../commons/constants/websocket';
import { getTenantInfo } from '../../commons/tenant-info';
import webRTC from '../../components/phone-call/webrtc';
import { CALL_STATUS, CALL_STOP_REASON } from '../../components/phone-call/constants';
export var stopCallRequest = createAction(actions.STOP_CALL + ".REQUEST");
export var stopCall = function stopCall(callInfo, _ref) {
  var stopReason = _ref.stopReason,
      totalDuration = _ref.totalDuration;
  return /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch) {
      var payload;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // webRTC stop call
              webRTC.stopCall();

              if (_get(callInfo, 'id')) {
                _context.next = 3;
                break;
              }

              return _context.abrupt("return");

            case 3:
              payload = _extends({}, callInfo, {
                stopReason: stopReason,
                totalDuration: stopReason === CALL_STOP_REASON.SUBSCRIBER_AUTO_STOP_WHEN_TIMEOUT ? 0 : totalDuration,
                status: stopReason === CALL_STOP_REASON.SUBSCRIBER_AUTO_STOP_WHEN_TIMEOUT || callInfo.status !== CALL_STATUS.IN_PROGRESS ? CALL_STATUS.CUSTOMER_CANCELED : CALL_STATUS.COMPLETED
              });
              dispatch(stopCallRequest({
                status: payload.status
              }));
              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.STOP_CALL,
                payload: payload,
                tenantInfo: getTenantInfo()
              });

            case 6:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function (_x) {
      return _ref2.apply(this, arguments);
    };
  }();
};
